=========================
Magnum Installation Guide
=========================

The Container Infrastructure Management service is a collection of components
that provides support to manage different container orchestration engines(COE)
like Kubernetes, Mesos and Swarm.

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Guides <http://docs.openstack.org/#install-guides>`_.
It is recommended to follow the `Container Infrastructure Management Service
<https://docs.openstack.org/project-install-guide/container-infrastructure-management>`_
section from the OpenStack Installation Tutorials. This chapter contains the
following sections:

.. toctree::
   :maxdepth: 1

   install-guide-from-source
